@@ -94,6 +94,8 @@ public class KinesisStreamProxyProvider {
         private final Map<String, Set<String>> efoConsumerRegistration = new HashMap<>();
         private final Set<String> consumersCurrentlyDeleting = new HashSet<>();
 
+        private int totalGetRecordsCall = 0;
+
         @Override
         public StreamDescriptionSummary getStreamDescriptionSummary(String streamArn) {
             return StreamDescriptionSummary.builder()
@@ -137,6 +139,7 @@ public class KinesisStreamProxyProvider {
                 String shardId,
                 StartingPosition startingPosition,
                 int maxRecordsToGet) {
+            totalGetRecordsCall++;
             ShardHandle shardHandle = new ShardHandle(streamArn, shardId);
 
             if (getRecordsExceptionSupplier != null) {
@@ -350,6 +353,10 @@ public class KinesisStreamProxyProvider {
             return closed;
         }
 
+        public int getTotalGetRecordsCall() {
+            return totalGetRecordsCall;
+        }
+
         private static class ShardHandle {
             private final String streamArn;
             private final String shardId;
