@@ -25,6 +25,7 @@ import org.apache.flink.connector.base.source.reader.RecordEmitter;
 import org.apache.flink.connector.base.source.reader.SingleThreadMultiplexSourceReaderBase;
 import org.apache.flink.connector.base.source.reader.fetcher.SingleThreadFetcherManager;
 import org.apache.flink.connector.dynamodb.source.enumerator.event.SplitsFinishedEvent;
+import org.apache.flink.connector.dynamodb.source.enumerator.event.SplitsFinishedEventContext;
 import org.apache.flink.connector.dynamodb.source.metrics.DynamoDbStreamsShardMetrics;
 import org.apache.flink.connector.dynamodb.source.split.DynamoDbStreamsShardSplit;
 import org.apache.flink.connector.dynamodb.source.split.DynamoDbStreamsShardSplitState;
@@ -32,6 +33,7 @@ import org.apache.flink.connector.dynamodb.source.split.DynamoDbStreamsShardSpli
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import software.amazon.awssdk.services.dynamodb.model.Record;
+import software.amazon.awssdk.services.dynamodb.model.Shard;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -41,6 +43,7 @@ import java.util.Map;
 import java.util.NavigableMap;
 import java.util.Set;
 import java.util.TreeMap;
+import java.util.stream.Collectors;
 
 /**
  * Coordinates the reading from assigned splits. Runs on the TaskManager.
@@ -55,6 +58,7 @@ public class DynamoDbStreamsSourceReader<T>
     private static final Logger LOG = LoggerFactory.getLogger(DynamoDbStreamsSourceReader.class);
     private final Map<String, DynamoDbStreamsShardMetrics> shardMetricGroupMap;
     private final NavigableMap<Long, Set<DynamoDbStreamsShardSplit>> splitFinishedEvents;
+    private final Map<String, List<Shard>> childShardIdMap;
     private long currentCheckpointId;
 
     public DynamoDbStreamsSourceReader(
@@ -62,10 +66,12 @@ public class DynamoDbStreamsSourceReader<T>
             RecordEmitter<Record, T, DynamoDbStreamsShardSplitState> recordEmitter,
             Configuration config,
             SourceReaderContext context,
+            Map<String, List<Shard>> childShardIdMap,
             Map<String, DynamoDbStreamsShardMetrics> shardMetricGroupMap) {
         super(splitFetcherManager, recordEmitter, config, context);
         this.shardMetricGroupMap = shardMetricGroupMap;
         this.splitFinishedEvents = new TreeMap<>();
+        this.childShardIdMap = childShardIdMap;
         this.currentCheckpointId = Long.MIN_VALUE;
     }
 
@@ -83,19 +89,39 @@ public class DynamoDbStreamsSourceReader<T>
         splitFinishedEvents.computeIfAbsent(currentCheckpointId, k -> new HashSet<>());
         finishedSplitIds.values().stream()
                 .map(
-                        finishedSplit ->
-                                new DynamoDbStreamsShardSplit(
-                                        finishedSplit.getStreamArn(),
-                                        finishedSplit.getShardId(),
-                                        finishedSplit.getNextStartingPosition(),
-                                        finishedSplit
-                                                .getDynamoDbStreamsShardSplit()
-                                                .getParentShardId(),
-                                        true))
+                        finishedSplit -> {
+                            List<Shard> childSplits = new ArrayList<>();
+                            String finishedSplitId = finishedSplit.getSplitId();
+                            if (childShardIdMap.containsKey(finishedSplitId)) {
+                                List<Shard> childSplitIdsOfFinishedSplit =
+                                        childShardIdMap.get(finishedSplitId);
+                                childSplits.addAll(childSplitIdsOfFinishedSplit);
+                            }
+                            return new DynamoDbStreamsShardSplit(
+                                    finishedSplit.getStreamArn(),
+                                    finishedSplit.getShardId(),
+                                    finishedSplit.getNextStartingPosition(),
+                                    finishedSplit.getDynamoDbStreamsShardSplit().getParentShardId(),
+                                    childSplits,
+                                    true);
+                        })
                 .forEach(split -> splitFinishedEvents.get(currentCheckpointId).add(split));
 
+        Set<SplitsFinishedEventContext> splitsFinishedEventContextMap =
+                finishedSplitIds.values().stream()
+                        .map(DynamoDbStreamsShardSplitState::getSplitId)
+                        .map(
+                                finishedSplitId ->
+                                        new SplitsFinishedEventContext(
+                                                finishedSplitId,
+                                                childShardIdMap.getOrDefault(
+                                                        finishedSplitId, Collections.emptyList())))
+                        .peek(context -> childShardIdMap.remove(context.getSplitId()))
+                        .collect(Collectors.toSet());
+
+        LOG.info("Sending splits finished event to coordinator: {}", splitsFinishedEventContextMap);
         context.sendSourceEventToCoordinator(
-                new SplitsFinishedEvent(new HashSet<>(finishedSplitIds.keySet())));
+                new SplitsFinishedEvent(splitsFinishedEventContextMap));
         finishedSplitIds.keySet().forEach(this::unregisterShardMetricGroup);
     }
 
@@ -121,8 +147,10 @@ public class DynamoDbStreamsSourceReader<T>
                 // buffer. If the next checkpoint doesn't complete,
                 // we would go back to the previous checkpointed
                 // state which will again replay these split finished events.
+                SplitsFinishedEventContext splitsFinishedEventContext =
+                        new SplitsFinishedEventContext(split.splitId(), split.getChildSplits());
                 context.sendSourceEventToCoordinator(
-                        new SplitsFinishedEvent(Collections.singleton(split.splitId())));
+                        new SplitsFinishedEvent(Collections.singleton(splitsFinishedEventContext)));
             } else {
                 dynamoDbStreamsShardSplits.add(split);
             }
