@@ -23,7 +23,11 @@ import org.apache.flink.api.connector.source.SourceSplit;
 import org.apache.flink.connector.base.source.reader.splitreader.SplitReader;
 import org.apache.flink.connector.dynamodb.source.enumerator.DynamoDbStreamsSourceEnumerator;
 
+import software.amazon.awssdk.services.dynamodb.model.Shard;
+
+import java.util.List;
 import java.util.Objects;
+import java.util.stream.Collectors;
 
 import static org.apache.flink.util.Preconditions.checkNotNull;
 
@@ -41,6 +45,7 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
     private final StartingPosition startingPosition;
     private final String parentShardId;
     private final boolean isFinished;
+    private final List<Shard> childSplits;
 
     public DynamoDbStreamsShardSplit(
             String streamArn,
@@ -55,6 +60,25 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
             String shardId,
             StartingPosition startingPosition,
             String parentShardId,
+            List<Shard> childSplits) {
+        this(streamArn, shardId, startingPosition, parentShardId, childSplits, false);
+    }
+
+    public DynamoDbStreamsShardSplit(
+            String streamArn,
+            String shardId,
+            StartingPosition startingPosition,
+            String parentShardId,
+            boolean isFinished) {
+        this(streamArn, shardId, startingPosition, parentShardId, List.of(), isFinished);
+    }
+
+    public DynamoDbStreamsShardSplit(
+            String streamArn,
+            String shardId,
+            StartingPosition startingPosition,
+            String parentShardId,
+            List<Shard> childSplits,
             boolean isFinished) {
         checkNotNull(streamArn, "streamArn cannot be null");
         checkNotNull(shardId, "shardId cannot be null");
@@ -65,6 +89,7 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
         this.startingPosition = startingPosition;
         this.parentShardId = parentShardId;
         this.isFinished = isFinished;
+        this.childSplits = childSplits;
     }
 
     @Override
@@ -92,6 +117,10 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
         return isFinished;
     }
 
+    public List<Shard> getChildSplits() {
+        return childSplits;
+    }
+
     @Override
     public String toString() {
         return "DynamoDbStreamsShardSplit{"
@@ -108,6 +137,11 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
                 + "]"
                 + ", isFinished="
                 + isFinished
+                + ", childSplitIds=["
+                + childSplits.stream().map(Shard::toString).collect(Collectors.joining(","))
+                + "], "
+                + ", isFinished="
+                + isFinished
                 + "}";
     }
 
@@ -124,11 +158,13 @@ public final class DynamoDbStreamsShardSplit implements SourceSplit {
                 && Objects.equals(shardId, that.shardId)
                 && Objects.equals(startingPosition, that.startingPosition)
                 && Objects.equals(parentShardId, that.parentShardId)
-                && Objects.equals(isFinished, that.isFinished);
+                && Objects.equals(isFinished, that.isFinished)
+                && Objects.equals(childSplits, that.childSplits);
     }
 
     @Override
     public int hashCode() {
-        return Objects.hash(streamArn, shardId, startingPosition, parentShardId, isFinished);
+        return Objects.hash(
+                streamArn, shardId, startingPosition, parentShardId, isFinished, childSplits);
     }
 }
